<?php

/**
 * @file
 * Contains \Drupal\forward\ForwardAccessChecker.
 */

namespace Drupal\forward;

use Drupal\Core\Entity\EntityInterface;

/**
 * Defines a class for checking whether a Forward link or form can be diplayed within a given context.
 */
class ForwardAccessChecker implements ForwardAccessCheckerInterface {

  /**
   * {@inheritdoc}
   */
  public function isAllowed(array $settings, EntityInterface $entity = NULL, $view_mode = NULL, $entity_type = NULL, $bundle = NULL) {
    // Full and default are synonymous
    if ($view_mode == 'default') {
      $view_mode = 'full';
    }
    // Check permission
    $show =  \Drupal::currentUser()->hasPermission('access forward');
    // Check view mode
    if ($show && $view_mode) {
      $show = !empty($settings['forward_view_' . $view_mode]);
    }
    // Check entity type
    if ($show) {
      if ($entity) {
        $entity_type = $entity->getEntityTypeId();
      }
      $show = $entity_type ? !empty($settings['forward_entity_' . $entity_type]) : FALSE;
    }
    // Check entity bundle
    if ($show) {
      if ($entity) {
        $bundle = $entity->bundle();
      }
      $show = ($entity_type && $bundle) ? !empty($settings['forward_' . $entity_type . '_' . $bundle]) : FALSE;
    }
    return $show; 
  }
}
