<?php

/**
 * @file
 * Contains \Drupal\forward\ForwardLinkBuilder.
 */

namespace Drupal\forward;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Defines a class for building markup for a Forward link on an entity.
 */
class ForwardLinkBuilder implements ForwardLinkBuilderInterface {

  /**
   * Build a link
   */
  private function buildLink(EntityInterface $entity, array $settings) {
    $token_service = \Drupal::token();

    $token = ['forward' => ['entity' => $entity]];
    $title = $token_service->replace($settings['forward_interface_title'], $token);
    $title_text = $title;

    $html = FALSE;
    // Output the correct style of link
    $default_icon = drupal_get_path('module', 'forward') . '/images/forward.gif';
    $custom_icon = $settings['forward_link_icon'];
    $link_style = $settings['forward_link_style'];
    switch ($link_style) {
      // text only is a "noop" since the title text is already setup above

      // image only
      case 1:
        $img = $custom_icon ? $custom_icon : $default_icon;
        $render_array = array('#theme' => 'image', '#uri' => $img, '#alt' => $title, '#attributes' => array('class' => array('forward-icon')));
        $title =  \Drupal::service('renderer')->render($render_array);
        $html = TRUE;
        break;
      // image and text
      case 2:
        $img = $custom_icon ? $custom_icon : $default_icon;
        $render_array = array(
          'image' => array('#theme' => 'image', '#uri' => $img, '#alt' => $title, '#attributes' => array('class' => array('forward-icon', 'forward-icon-margin'))),
          'text' => array('#markup' => $title_text),
        );
        $title =  \Drupal::service('renderer')->render($render_array);
        $html = TRUE;
        break;
    }
    $attributes = array(
      'title' => $title_text,
      'class' => array('forward-page'),
    );
    if ($settings['forward_link_nofollow']) {
      $attributes['rel'] = 'nofollow';
    }

    $entity_id = $entity->id();
    $entity_type = $entity->getEntityTypeId();
    $url = Url::fromUri("internal:/forward/{$entity_type}/{$entity_id}");
    $url->setOptions(
      array(
        'html' => $html,
        'attributes' => $attributes,
      )
    );
    return array('title' => $title, 'url' => $url, 'attributes' => $attributes);
  }

  /**
   * {@inheritdoc}
   */
  public function buildForwardEntityLink(EntityInterface $entity, array $settings) {
    $link = $this->buildLink($entity, $settings);
    if ($settings['forward_link_inline']) {
      // Render the link inline with other node links
      $render_array = array(
        '#theme' => 'links',
        '#links' => array(
          'forward' => array(
            'url' => $link['url'],
            'title' => $link['title'],
            'attributes' => $link['attributes'],
          ),
        ),
        '#attributes' => array(
          'class' => array('links', 'inline'),
        ),
        '#attached' => array(
          'library' => array(
            'forward/forward',
          ),
        ),
        '#weight' => $settings['forward_interface_weight'],
      );
    } else {
      // Standard render
      $render_array = array(
        '#markup' => \Drupal::l($link['title'], $link['url'], $link['attributes']),
        '#attached' => array(
          'library' => array(
            'forward/forward',
          ),
        ),
        '#weight' => $settings['forward_interface_weight'],
      );
    }
    return $render_array;
  }
}
