<?php

/**
 * @file
 * Contains \Drupal\forward\Plugin\DsField\ForwardLink.
 */

namespace Drupal\forward\Plugin\DsField;

use Drupal\ds\Plugin\DsField\DsFieldBase;

/**
 * Forward link plugin.
 *
 * @DsField(
 *   id = "forward_link",
 *   title = @Translation("Forward link"),
 *   entity_type = "node"
 * )
 */
class ForwardLink extends DsFieldBase {
  private $settings;

  /**
   * Constructs a Display Suite field plugin.
   */
  public function __construct($configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $config = \Drupal::configFactory()->getEditable('forward.settings');
    // Force standard render since inline render is part of the "Links" DS element
    $config->set('forward_link_inline', FALSE);
    $this->settings = $config->get();
  }

  /**
   * {@inheritdoc}
   */
  public function isAllowed() {
    return \Drupal::service('forward.access_checker')->isAllowed($this->settings, $this->entity(), $this->viewMode(), $this->getEntityTypeId(), $this->bundle());
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $render_array = array();

    // Build the link unless Forward is rendering an email
    $config = $this->getConfiguration();
    if (empty($config['build']['#forward_build'])) {
      $render_array = \Drupal::service('forward.link_builder')->buildForwardEntityLink($this->entity(), $this->settings);
    }

    return $render_array;
  }
}
